@@ -116,12 +116,7 @@ class Shape:
 
     @deprecated(reason='Use the .id property')
     def GetID(self):
-        """
-        TODO:  Make this a property
-        Get the ID number of the shape.
 
-        @return int
-        """
         return self._id
 
     @deprecated(reason='Use the .id property')
@@ -603,9 +598,9 @@ class Shape:
         # Get the offsets and the ratio between the shape (view) and the
         # shape model (ShapeModel) given by the frame where the shape
         # is displayed.
-        ratio = self.GetDiagram().GetPanel().GetCurrentZoom()
-        dx: int = round(self.GetDiagram().GetPanel().GetXOffset())
-        dy: int = round(self.GetDiagram().GetPanel().GetYOffset())
+        ratio = self.GetDiagram().GetPanel().currentZoom
+        dx: int = round(self.GetDiagram().GetPanel().xOffSet)
+        dy: int = round(self.GetDiagram().GetPanel().yOffSet)
 
         # calculation of the shape (view) coordinates in the light of the offsets and ratio
         x: int = round(ratio * mx) + dx
@@ -631,15 +626,16 @@ class Shape:
         # Get the offsets and the ratio between the shape (view) and the
         # shape model (ShapeModel) given by the frame where the shape
         # is displayed.
+        from miniogl.DiagramFrame import DiagramFrame
         diagram = self.GetDiagram()
-        panel   = diagram.GetPanel()   # to enable debugging and unit tests
+        panel: DiagramFrame   = diagram.GetPanel()   # to enable debugging and unit tests
 
         # ratio = self.GetDiagram().GetPanel().GetCurrentZoom()
         # dx = self.GetDiagram().GetPanel().GetXOffset()
         # dy = self.GetDiagram().GetPanel().GetYOffset()
-        ratio = panel.GetCurrentZoom()
-        dx    = panel.GetXOffset()
-        dy    = panel.GetYOffset()
+        ratio = panel.currentZoom
+        dx    = panel.xOffSet
+        dy    = panel.yOffSet
 
         #  get the coordinates of this shape
         x, y = self.GetPosition()
