@@ -20,7 +20,7 @@ from miniogl.ShapeEventHandler import ShapeEventHandler
 from ogl.OglLink import OglLink
 from ogl.OglUtils import OglUtils
 
-from ogl.events.OglEventType import OglEventType
+from ogl.events.OglEvents import OglEventType
 from ogl.events.OglEventEngine import OglEventEngine
 
 from ogl.preferences.OglPreferences import OglPreferences
@@ -168,7 +168,7 @@ class OglObject(RectangleShape, ShapeEventHandler):
             y:  The new ordinate
         """
         if self.eventEngine is not None:        # we might be associated with a diagram yet
-            self.eventEngine.sendEvent(OglEventType.ProjectModified)
+            self.eventEngine.sendEvent(OglEventType.DiagramFrameModified)
         RectangleShape.SetPosition(self, x, y)
 
     def SetSelected(self, state=True):
