@@ -4,6 +4,8 @@ from typing import cast
 from logging import Logger
 from logging import getLogger
 
+from deprecated import deprecated
+from pyutmodel.PyutSDInstance import PyutSDInstance
 from wx import BLACK_DASHED_PEN
 from wx import PENSTYLE_LONG_DASH
 
@@ -11,7 +13,6 @@ from wx import Colour
 from wx import Pen
 
 from miniogl.AnchorPoint import AnchorPoint
-from miniogl.Diagram import Diagram
 from miniogl.LineShape import LineShape
 from miniogl.RectangleShape import RectangleShape
 
@@ -26,71 +27,55 @@ class OglSDInstance(OglObject):
     This class is an OGL object for class diagram instance (vertical line)
 
     Instantiated by UmlClassDiagramFrame
+    To actually place one of these on a UML Frame requires use of the SDHelper class
     """
-    DEFAULT_WIDTH: int = 100
+    DEFAULT_WIDTH:  int = 100
     DEFAULT_HEIGHT: int = 400
 
-    def __init__(self, pyutObject, parentFrame):
+    def __init__(self, pyutObject: PyutSDInstance):
         """
         """
-        self._parentFrame = parentFrame
-        self._instanceYPosition: int = 50       # Start of instances position
-
         self.logger: Logger = getLogger(__name__)
 
-        diagram: Diagram = self._parentFrame.GetDiagram()
-
-        # OglObject.__init__(self, pyutObject, DEFAULT_WIDTH, DEFAULT_HEIGHT)
         super().__init__(pyutObject, OglSDInstance.DEFAULT_WIDTH, OglSDInstance.DEFAULT_HEIGHT)
 
-        diagram.AddShape(self)
+        self._instanceYPosition: int = 50       # Start of instances position
+
         self.SetDraggable(True)
         self.SetVisible(True)
         self.SetPen(Pen(Colour(200, 200, 255), 1, PENSTYLE_LONG_DASH))
         self.SetPosition(self.GetPosition()[0], self._instanceYPosition)
 
-        # Init lineShape
-        (srcX, srcY, dstX, dstY) = (OglSDInstance.DEFAULT_WIDTH // 2, 0,
-                                    OglSDInstance.DEFAULT_WIDTH // 2, OglSDInstance.DEFAULT_HEIGHT
-                                    )
-
-        (src, dst) = (AnchorPoint(srcX, srcY, self), AnchorPoint(dstX, dstY, self))
-        for el in [src, dst]:
-            el.SetVisible(False)
-            el.SetDraggable(False)
-        self._lifeLineShape: LineShape = LineShape(src, dst)
-        self.AppendChild(self._lifeLineShape)
-        self._lifeLineShape.SetParent(self)
-        self._lifeLineShape.SetDrawArrow(False)
-        self._lifeLineShape.SetDraggable(True)
-        self._lifeLineShape.SetPen(BLACK_DASHED_PEN)
-        self._lifeLineShape.SetVisible(True)
-        diagram.AddShape(self._lifeLineShape)
-        
-        # Instance box
-        self._instanceBox: RectangleShape = RectangleShape(0, 0, 100, 50)
-
-        self.AppendChild(self._instanceBox)
-        self._instanceBox.SetDraggable(False)
-        self._instanceBox.Resize = self.OnInstanceBoxResize
-        self._instanceBox.SetResizable(True)
-        self._instanceBox.SetParent(self)
-        diagram.AddShape(self._instanceBox)
-
-        # Text of the instance box
-        text = self._pyutObject.instanceName
-        self._instanceBoxText: OglInstanceName = OglInstanceName(pyutObject, 0, 20, text, self._instanceBox)
-        self.AppendChild(self._instanceBoxText)
-        diagram.AddShape(self._instanceBoxText)
+        self._lifeLine:     LineShape       = self._createLifeLine()
+        self._instance:     RectangleShape  = self._createInstance()
+        self._instanceName: OglInstanceName = self._createInstanceName(pyutSDInstance=pyutObject, instanceBox=self._instance)
         # TODO : set instance box size to the size of the text by invoking self._instanceBoxText.setSize()
 
+    @deprecated(reason="Use the property '.lifeline'")
     def getLifeLineShape(self):
         """
         Used by OGLSDMessage to use it as parent
 
         Returns: The lifeline object
         """
-        return self._lifeLineShape
+        return self._lifeLine
+
+    @property
+    def lifeline(self) -> LineShape:
+        """
+        Used by OGLSDMessage to use it as parent and
+
+        Returns: The lifeline object
+        """
+        return self._lifeLine
+
+    @property
+    def instance(self) -> RectangleShape:
+        return self._instance
+
+    @property
+    def instanceName(self) -> OglInstanceName:
+        return self._instanceName
 
     def OnInstanceBoxResize(self, sizer, width: int, height: int):
         """
@@ -106,8 +91,8 @@ class OglSDInstance(OglObject):
 
         @param double x, y : position of the sizer
         """
-        RectangleShape.Resize(self._instanceBox, sizer, width, height)
-        size = self._instanceBox.GetSize()
+        RectangleShape.Resize(self._instance, sizer, width, height)
+        size = self._instance.GetSize()
         self.SetSize(size[0], self.GetSize()[1])
 
     def Resize(self, sizer, width: int, height: int):
@@ -128,8 +113,8 @@ class OglSDInstance(OglObject):
         # Set lifeline
         (myX, myY) = self.GetPosition()
         (w, h) = self.GetSize()
-        lineDst = self._lifeLineShape.GetDestination()
-        lineSrc = self._lifeLineShape.GetSource()
+        lineDst = self._lifeLine.GetDestination()
+        lineSrc = self._lifeLine.GetSource()
         lineSrc.SetDraggable(True)
         lineDst.SetDraggable(True)
         lineSrc.SetPosition(w // 2 + myX, 0 + myY)
@@ -146,7 +131,7 @@ class OglSDInstance(OglObject):
             except (ValueError, Exception) as e:
                 self.logger.error(f'Link update position error: {e}')
         # Set TextBox
-        RectangleShape.SetSize(self._instanceBox, width, self._instanceBox.GetSize()[1])
+        RectangleShape.SetSize(self._instance, width, self._instance.GetSize()[1])
 
     def SetPosition(self, x: int, y: int):
         """ 
@@ -155,20 +140,20 @@ class OglSDInstance(OglObject):
         y = self._instanceYPosition
         OglObject.SetPosition(self, x, y)
 
-    def Draw(self, dc, withChildren=False):
+    def Draw(self, dc, withChildren=True):
         """
-        Draw overload; update labels
+        Draw override
+        Args:
+            dc:
+            withChildren:  defaulted to True because of the child shapes
         """
         # Update labels
-        self._instanceBoxText.SetText(self._pyutObject.instanceName)
-
+        self._instanceName.SetText(self._pyutObject.instanceName)
         # Call parent's Draw method
         if self.IsSelected():
             self.SetVisible(True)
             self.SetPen(Pen(Colour(200, 200, 255), 1, PENSTYLE_LONG_DASH))
 
-        # Draw
-        # OglObject.Draw(self, dc, withChildren)
         super().Draw(dc=dc, withChildren=withChildren)
 
     def OnLeftUp(self, event):
@@ -177,6 +162,61 @@ class OglSDInstance(OglObject):
         """
         self.SetPosition(self.GetPosition()[0], self._instanceYPosition)
 
+    def _createLifeLine(self) -> LineShape:
+        """
+
+        Returns:  The lifeline
+        """
+        (srcX, srcY, dstX, dstY) = (OglSDInstance.DEFAULT_WIDTH // 2, 0,
+                                    OglSDInstance.DEFAULT_WIDTH // 2, OglSDInstance.DEFAULT_HEIGHT
+                                    )
+
+        (src, dst) = (AnchorPoint(srcX, srcY, self), AnchorPoint(dstX, dstY, self))
+        for el in [src, dst]:
+            el.SetVisible(False)
+            el.SetDraggable(False)
+
+        lifeLineShape: LineShape = LineShape(src, dst)
+
+        lifeLineShape.SetParent(self)
+        lifeLineShape.SetDrawArrow(False)
+        lifeLineShape.SetDraggable(True)
+        lifeLineShape.SetPen(BLACK_DASHED_PEN)
+        lifeLineShape.SetVisible(True)
+
+        self.AppendChild(lifeLineShape)
+
+        return lifeLineShape
+
+    def _createInstance(self) -> RectangleShape:
+        """
+
+        Returns:  The instance box
+        """
+        instanceBox: RectangleShape = RectangleShape(0, 0, 100, 50)
+
+        instanceBox.SetDraggable(False)
+        instanceBox.Resize = self.OnInstanceBoxResize   # type: ignore
+        instanceBox.SetResizable(True)
+        instanceBox.SetParent(self)
+
+        self.AppendChild(instanceBox)
+
+        return instanceBox
+
+    def _createInstanceName(self, pyutSDInstance: PyutSDInstance, instanceBox: RectangleShape) -> OglInstanceName:
+        """
+
+        Returns:  An OglInstanceName
+        """
+        text: str = self._pyutObject.instanceName
+
+        oglInstanceName: OglInstanceName = OglInstanceName(pyutSDInstance, 0, 20, text, instanceBox)
+
+        self.AppendChild(oglInstanceName)
+
+        return oglInstanceName
+
     def __str__(self) -> str:
         instanceName: str = self._pyutObject.instanceName
         return f'OglSDInstance[{self._id=} {instanceName=}]'
